@@ -1,12 +1,12 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
+
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
-  
+
     http://www.imagemagick.org/script/license.php
-  
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -32,12 +32,12 @@ extern WandExport char
   *MagickGetImageSignature(MagickWand *),
   *MagickIdentifyImage(MagickWand *);
 
-extern WandExport CompositeOperator
-  MagickGetImageCompose(MagickWand *);
-
 extern WandExport ColorspaceType
   MagickGetImageColorspace(MagickWand *);
 
+extern WandExport CompositeOperator
+  MagickGetImageCompose(MagickWand *);
+
 extern WandExport CompressionType
   MagickGetImageCompression(MagickWand *);
 
@@ -47,6 +47,7 @@ extern WandExport DisposeType
 extern WandExport double
   *MagickGetImageChannelDistortions(MagickWand *,const MagickWand *,
     const MetricType),
+  MagickGetImageFuzz(MagickWand *),
   MagickGetImageGamma(MagickWand *),
   MagickGetImageTotalInkDensity(MagickWand *);
 
@@ -84,7 +85,12 @@ extern WandExport MagickBooleanType
   MagickAnnotateImage(MagickWand *,const DrawingWand *,const double,
     const double,const double,const char *),
   MagickAnimateImages(MagickWand *,const char *),
+  MagickAutoGammaImage(MagickWand *),
+  MagickAutoGammaImageChannel(MagickWand *,const ChannelType),
+  MagickAutoLevelImage(MagickWand *),
+  MagickAutoLevelImageChannel(MagickWand *,const ChannelType),
   MagickBlackThresholdImage(MagickWand *,const PixelWand *),
+  MagickBlueShiftImage(MagickWand *,const double),
   MagickBlurImage(MagickWand *,const double,const double),
   MagickBlurImageChannel(MagickWand *,const ChannelType,const double,
     const double),
@@ -93,10 +99,13 @@ extern WandExport MagickBooleanType
   MagickCharcoalImage(MagickWand *,const double,const double),
   MagickChopImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
+  MagickClampImage(MagickWand *),
+  MagickClampImageChannel(MagickWand *,const ChannelType),
   MagickClipImage(MagickWand *),
   MagickClipImagePath(MagickWand *,const char *,const MagickBooleanType),
   MagickClutImage(MagickWand *,const MagickWand *),
   MagickClutImageChannel(MagickWand *,const ChannelType,const MagickWand *),
+  MagickColorDecisionListImage(MagickWand *,const char *),
   MagickColorizeImage(MagickWand *,const PixelWand *,const PixelWand *),
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
@@ -131,6 +140,9 @@ extern WandExport MagickBooleanType
   MagickEvaluateImage(MagickWand *,const MagickEvaluateOperator,const double),
   MagickEvaluateImageChannel(MagickWand *,const ChannelType,
     const MagickEvaluateOperator,const double),
+  MagickExportImagePixels(MagickWand *,const long,const long,
+    const unsigned long,const unsigned long,const char *,const StorageType,
+    void *),
   MagickExtentImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickFlipImage(MagickWand *),
@@ -138,8 +150,13 @@ extern WandExport MagickBooleanType
     const double,const PixelWand *,const long,const long,
     const MagickBooleanType),
   MagickFlopImage(MagickWand *),
+  MagickForwardFourierTransformImage(MagickWand *,const MagickBooleanType),
   MagickFrameImage(MagickWand *,const PixelWand *,const unsigned long,
     const unsigned long,const long,const long),
+  MagickFunctionImage(MagickWand *,const MagickFunction,const unsigned long,
+    const double *),
+  MagickFunctionImageChannel(MagickWand *,const ChannelType,
+    const MagickFunction,const unsigned long,const double *),
   MagickGammaImage(MagickWand *,const double),
   MagickGammaImageChannel(MagickWand *,const ChannelType,const double),
   MagickGaussianBlurImage(MagickWand *,const double,const double),
@@ -150,27 +167,33 @@ extern WandExport MagickBooleanType
   MagickGetImageBluePrimary(MagickWand *,double *,double *),
   MagickGetImageBorderColor(MagickWand *,PixelWand *),
   MagickGetImageChannelDistortion(MagickWand *,const MagickWand *,
-    const ChannelType, const MetricType,double *),
-  MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
+    const ChannelType,const MetricType,double *),
+  MagickGetImageChannelKurtosis(MagickWand *,const ChannelType,double *,
     double *),
   MagickGetImageChannelMean(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageChannelRange(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageColormapColor(MagickWand *,const unsigned long,PixelWand *),
+  MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
+    double *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
   MagickGetImageLength(MagickWand *,MagickSizeType *),
   MagickGetImagePage(MagickWand *,unsigned long *,unsigned long *,long *,
     long *),
   MagickGetImagePixelColor(MagickWand *,const long,const long,PixelWand *),
-  MagickGetImagePixels(MagickWand *,const long,const long,const unsigned long,
-    const unsigned long,const char *,const StorageType,void *),
   MagickGetImageRange(MagickWand *,double *,double *),
   MagickGetImageRedPrimary(MagickWand *,double *,double *),
   MagickGetImageResolution(MagickWand *,double *,double *),
   MagickGetImageWhitePoint(MagickWand *,double *,double *),
+  MagickHaldClutImage(MagickWand *,const MagickWand *),
+  MagickHaldClutImageChannel(MagickWand *,const ChannelType,const MagickWand *),
   MagickHasNextImage(MagickWand *),
   MagickHasPreviousImage(MagickWand *),
   MagickImplodeImage(MagickWand *,const double),
+  MagickImportImagePixels(MagickWand *,const long,const long,
+    const unsigned long,const unsigned long,const char *,const StorageType,
+    const void *),
+  MagickInverseFourierTransformImage(MagickWand *,const MagickBooleanType),
   MagickLabelImage(MagickWand *,const char *),
   MagickLevelImage(MagickWand *,const double,const double,const double),
   MagickLevelImageChannel(MagickWand *,const ChannelType,const double,
@@ -230,6 +253,7 @@ extern WandExport MagickBooleanType
   MagickRemoveImage(MagickWand *),
   MagickResampleImage(MagickWand *,const double,const double,const FilterTypes,
     const double),
+  MagickResetImagePage(MagickWand *,const char *),
   MagickResizeImage(MagickWand *,const unsigned long,const unsigned long,
     const FilterTypes,const double),
   MagickRollImage(MagickWand *,const long,const long),
@@ -238,6 +262,9 @@ extern WandExport MagickBooleanType
   MagickScaleImage(MagickWand *,const unsigned long,const unsigned long),
   MagickSegmentImage(MagickWand *,const ColorspaceType,const MagickBooleanType,
     const double,const double),
+  MagickSelectiveBlurImage(MagickWand *,const double,const double,const double),
+  MagickSelectiveBlurImageChannel(MagickWand *,const ChannelType,const double,
+    const double,const double),
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
@@ -251,22 +278,22 @@ extern WandExport MagickBooleanType
   MagickSetImageClipMask(MagickWand *,const MagickWand *),
   MagickSetImageColormapColor(MagickWand *,const unsigned long,
     const PixelWand *),
+  MagickSetImageColorspace(MagickWand *,const ColorspaceType),
   MagickSetImageCompose(MagickWand *,const CompositeOperator),
   MagickSetImageCompression(MagickWand *,const CompressionType),
   MagickSetImageDelay(MagickWand *,const unsigned long),
   MagickSetImageDepth(MagickWand *,const unsigned long),
   MagickSetImageDispose(MagickWand *,const DisposeType),
-  MagickSetImageColorspace(MagickWand *,const ColorspaceType),
   MagickSetImageCompressionQuality(MagickWand *,const unsigned long),
-  MagickSetImageGreenPrimary(MagickWand *,const double,const double),
-  MagickSetImageGamma(MagickWand *,const double),
   MagickSetImageExtent(MagickWand *,const unsigned long,const unsigned long),
   MagickSetImageFilename(MagickWand *,const char *),
-  MagickSetImageGravity(MagickWand *,const GravityType),
   MagickSetImageFormat(MagickWand *,const char *),
+  MagickSetImageFuzz(MagickWand *,const double),
+  MagickSetImageGamma(MagickWand *,const double),
+  MagickSetImageGravity(MagickWand *,const GravityType),
+  MagickSetImageGreenPrimary(MagickWand *,const double,const double),
   MagickSetImageInterlaceScheme(MagickWand *,const InterlaceType),
-  MagickSetImageInterpolateMethod(MagickWand *,
-    const InterpolatePixelMethod),
+  MagickSetImageInterpolateMethod(MagickWand *,const InterpolatePixelMethod),
   MagickSetImageIterations(MagickWand *,const unsigned long),
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
   MagickSetImageMatteColor(MagickWand *,const PixelWand *),
@@ -274,9 +301,6 @@ extern WandExport MagickBooleanType
   MagickSetImageOrientation(MagickWand *,const OrientationType),
   MagickSetImagePage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
-  MagickResetImagePage(MagickWand *,const char *),
-  MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
-    const unsigned long,const char *,const StorageType,const void *),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
@@ -285,8 +309,8 @@ extern WandExport MagickBooleanType
   MagickSetImageType(MagickWand *,const ImageType),
   MagickSetImageUnits(MagickWand *,const ResolutionType),
   MagickSetImageWhitePoint(MagickWand *,const double,const double),
-  MagickShadeImage(MagickWand *,const MagickBooleanType,const double,const 
-    double),
+  MagickShadeImage(MagickWand *,const MagickBooleanType,const double,
+    const double),
   MagickShadowImage(MagickWand *,const double,const double,const long,
     const long),
   MagickSharpenImage(MagickWand *,const double,const double),
@@ -300,12 +324,15 @@ extern WandExport MagickBooleanType
     const MagickBooleanType,const double,const double),
   MagickSketchImage(MagickWand *,const double,const double,const double),
   MagickSolarizeImage(MagickWand *,const double),
+  MagickSparseColorImage(MagickWand *,const ChannelType,const SparseColorMethod,
+    const unsigned long,const double *),
   MagickSpliceImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickSpreadImage(MagickWand *,const double),
   MagickStripImage(MagickWand *),
   MagickSwirlImage(MagickWand *,const double),
   MagickTintImage(MagickWand *,const PixelWand *,const PixelWand *),
+  MagickTransformImageColorspace(MagickWand *,const ColorspaceType),
   MagickTransposeImage(MagickWand *),
   MagickTransverseImage(MagickWand *),
   MagickThresholdImage(MagickWand *,const double),
@@ -353,11 +380,12 @@ extern WandExport MagickWand
     const char *,const MontageMode,const char *),
   *MagickOptimizeImageLayers(MagickWand *),
   *MagickPreviewImages(MagickWand *wand,const PreviewType),
+  *MagickSimilarityImage(MagickWand *,const MagickWand *,RectangleInfo *,
+    double *),
   *MagickSteganoImage(MagickWand *,const MagickWand *,const long),
   *MagickStereoImage(MagickWand *,const MagickWand *),
   *MagickTextureImage(MagickWand *,const MagickWand *),
-  *MagickTransformImage(MagickWand *,const char *,const char *),
-  *NewMagickWandFromImage(const Image *);
+  *MagickTransformImage(MagickWand *,const char *,const char *);
 
 extern WandExport OrientationType
   MagickGetImageOrientation(MagickWand *);
@@ -389,7 +417,8 @@ extern WandExport unsigned long
   MagickGetNumberImages(MagickWand *);
 
 extern WandExport VirtualPixelMethod
-  MagickGetImageVirtualPixelMethod(MagickWand *);
+  MagickGetImageVirtualPixelMethod(MagickWand *),
+  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
